==> qmmp-1.6.9.tar.bz2: qmmp-1.6.9/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation>Skriv ut uppspelningsstatus</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Skriv ut formaterat spårnamn (exempel: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="33"/>
        <source>Print --nowplaying syntax</source>
        <translation>Skriv ut --nowplaying syntax</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation>Syntax:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation>%p - artist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation>%a - album</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation>%aa - album artist</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation>%t - titel</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation>%n - spår</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation>%g - genre</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation>%c - kommentar</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation>%C - kompositör</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation>%D - skivnummer</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation>%f - filnamn</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation>%y - år</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation>%{filesize} - filstorlek</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_2.3.0.orig.tar.bz2: qmmp-2.3.0/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="30"/>
        <source>Print playback status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="31"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="32"/>
        <source>Print --nowplaying syntax</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>Syntax:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%p - artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%a - album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%aa - album artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%t - title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%n - track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%NN - 2-digit track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%g - genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%c - comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%C - composer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%D - disc number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="105"/>
        <source>%f - file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="106"/>
        <source>%F - full path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="107"/>
        <source>%y - year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="108"/>
        <source>%l - duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="109"/>
        <source>%{bitrate} - bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="110"/>
        <source>%{samplerate} - sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="111"/>
        <source>%{channels} - number of channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="112"/>
        <source>%{samplesize} - bits per sample</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="113"/>
        <source>%{format} - format name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="114"/>
        <source>%{decoder} - decoder name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="115"/>
        <source>%{filesize} - file size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="116"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="117"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
